@@ -31,10 +31,12 @@ def guess_url(url):
 
     @param url: the URL to check
     @type url: unicode
-    @return: url with http:// or ftp:// prepended if it's detected as
+    @return: url with *http://* or *ftp://* prepended if it's detected as
         a http respective ftp URL.
     @rtype: unicode
     """
+    if url.lower().endswith(".html") and "/" not in url:
+        return url
     if url.lower().startswith("www."):
         # syntactic sugar
         return "http://%s" % url
