@@ -1,4 +1,3 @@
-# -*- coding: iso-8859-1 -*-
 # Copyright (C) 2000-2014 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
@@ -19,52 +18,33 @@ Handle FTP links.
 """
 
 import ftplib
-try:
-    from cStringIO import StringIO
-except ImportError:
-    # Python 3
-    from io import StringIO
+from io import StringIO
 
 from .. import log, LOG_CHECK, LinkCheckerError, mimeutil
-from . import proxysupport, httpurl, internpaturl, get_index_html
+from . import internpaturl, get_index_html
 from .const import WARN_FTP_MISSING_SLASH
 
 
-class FtpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
+class FtpUrl(internpaturl.InternPatternUrl):
     """
     Url link with ftp scheme.
     """
 
-    def reset (self):
+    def reset(self):
         """
         Initialize FTP url data.
         """
-        super(FtpUrl, self).reset()
+        super().reset()
         # list of files for recursion
         self.files = []
         # last part of URL filename
         self.filename = None
         self.filename_encoding = 'iso-8859-1'
 
-    def check_connection (self):
+    def check_connection(self):
         """
-        In case of proxy, delegate to HttpUrl. Else check in this
-        order: login, changing directory, list the file.
+        Check in this order: login, changing directory, list the file.
         """
-        # proxy support (we support only http)
-        self.set_proxy(self.aggregate.config["proxy"].get(self.scheme))
-        if self.proxy:
-            # using a (HTTP) proxy
-            http = httpurl.HttpUrl(self.base_url,
-                  self.recursion_level,
-                  self.aggregate,
-                  parent_url=self.parent_url,
-                  base_ref=self.base_ref,
-                  line=self.line,
-                  column=self.column,
-                  name=self.name)
-            http.build_url()
-            return http.check()
         self.login()
         self.negotiate_encoding()
         self.filename = self.cwd()
@@ -72,7 +52,7 @@ class FtpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
         self.files = []
         return None
 
-    def login (self):
+    def login(self):
         """Log into ftp server and check the welcome message."""
         self.url_connection = ftplib.FTP(timeout=self.aggregate.config["timeout"])
         if log.is_debug(LOG_CHECK):
@@ -91,32 +71,33 @@ class FtpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
                 # note that the info may change every time a user logs in,
                 # so don't add it to the url_data info.
                 log.debug(LOG_CHECK, "FTP info %s", info)
-                pass
             else:
                 raise LinkCheckerError(_("Got no answer from FTP server"))
         except EOFError as msg:
             raise LinkCheckerError(
-                      _("Remote host has closed connection: %(msg)s") % str(msg))
+                _("Remote host has closed connection: %(msg)s") % str(msg)
+            )
 
-    def negotiate_encoding (self):
+    def negotiate_encoding(self):
         """Check if server can handle UTF-8 encoded filenames.
         See also RFC 2640."""
         try:
             features = self.url_connection.sendcmd("FEAT")
         except ftplib.error_perm as msg:
             log.debug(LOG_CHECK, "Ignoring error when getting FTP features: %s" % msg)
-            pass
         else:
             log.debug(LOG_CHECK, "FTP features %s", features)
             if " UTF-8" in features.splitlines():
                 self.filename_encoding = "utf-8"
 
-    def cwd (self):
+    def cwd(self):
         """
         Change to URL parent directory. Return filename of last path
         component.
         """
-        path = self.urlparts[2].encode(self.filename_encoding, 'replace')
+        path = self.urlparts[2]
+        if isinstance(path, bytes):
+            path = path.decode(self.filename_encoding, 'replace')
         dirname = path.strip('/')
         dirs = dirname.split('/')
         filename = dirs.pop()
@@ -125,7 +106,7 @@ class FtpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
             self.url_connection.cwd(d)
         return filename
 
-    def listfile (self):
+    def listfile(self):
         """
         See if filename is in the current FTP directory.
         """
@@ -140,21 +121,24 @@ class FtpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
         if "%s/" % self.filename in files:
             if not self.url.endswith('/'):
                 self.add_warning(
-                         _("Missing trailing directory slash in ftp url."),
-                         tag=WARN_FTP_MISSING_SLASH)
+                    _("Missing trailing directory slash in ftp url."),
+                    tag=WARN_FTP_MISSING_SLASH,
+                )
                 self.url += '/'
             return
         raise ftplib.error_perm("550 File not found")
 
-    def get_files (self):
+    def get_files(self):
         """Get list of filenames in directory. Subdirectories have an
         ending slash."""
         files = []
-        def add_entry (line):
+
+        def add_entry(line):
             """Parse list line and add the entry it points to to the file
             list."""
             log.debug(LOG_CHECK, "Directory entry %r", line)
             from ..ftpparse import ftpparse
+
             fpo = ftpparse(line)
             if fpo is not None and fpo["name"]:
                 name = fpo["name"]
@@ -162,30 +146,33 @@ class FtpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
                     name += "/"
                 if fpo["trycwd"] or fpo["tryretr"]:
                     files.append(name)
+
         self.url_connection.dir(add_entry)
         return files
 
-    def is_parseable (self):
+    def is_parseable(self):
         """See if URL target is parseable for recursion."""
         if self.is_directory():
             return True
         if self.content_type in self.ContentMimetypes:
             return True
-        log.debug(LOG_CHECK, "URL with content type %r is not parseable.", self.content_type)
+        log.debug(
+            LOG_CHECK, "URL with content type %r is not parseable.", self.content_type
+        )
         return False
 
-    def is_directory (self):
+    def is_directory(self):
         """See if URL target is a directory."""
         # either the path is empty, or ends with a slash
         path = self.urlparts[2]
         return (not path) or path.endswith('/')
 
-    def set_content_type (self):
+    def set_content_type(self):
         """Set URL content type, or an empty string if content
         type could not be found."""
         self.content_type = mimeutil.guess_mimetype(self.url, read=self.get_content)
 
-    def read_content (self):
+    def read_content(self):
         """Return URL target content, or in case of directories a dummy HTML
         file with links to the files."""
         if self.is_directory():
@@ -197,18 +184,20 @@ class FtpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
             # download file in BINARY mode
             ftpcmd = "RETR %s" % self.filename
             buf = StringIO()
-            def stor_data (s):
+
+            def stor_data(s):
                 """Helper method storing given data"""
                 # limit the download size
                 if (buf.tell() + len(s)) > self.max_size:
                     raise LinkCheckerError(_("FTP file size too large"))
                 buf.write(s)
+
             self.url_connection.retrbinary(ftpcmd, stor_data)
             data = buf.getvalue()
             buf.close()
         return data
 
-    def close_connection (self):
+    def close_connection(self):
         """Release the open connection from the connection pool."""
         if self.url_connection is not None:
             try:
