@@ -1,4 +1,3 @@
-# -*- coding: iso-8859-1 -*-
 # Copyright (C) 2000-2014 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
@@ -16,12 +15,21 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 """Parse configuration files"""
 
-import ConfigParser
+from configparser import RawConfigParser
 import os
-from .. import LinkCheckerError, get_link_pat, LOG_CHECK, log, fileutil, plugins, logconf
+
+from .. import (
+    LinkCheckerError,
+    get_link_pat,
+    LOG_CHECK,
+    log,
+    fileutil,
+    plugins,
+    logconf,
+)
 
 
-def read_multiline (value):
+def read_multiline(value):
     """Helper function reading multiline values."""
     for line in value.splitlines():
         line = line.strip()
@@ -30,27 +38,29 @@ def read_multiline (value):
         yield line
 
 
-class LCConfigParser (ConfigParser.RawConfigParser, object):
+class LCConfigParser(RawConfigParser):
     """
     Parse a LinkChecker configuration file.
     """
 
-    def __init__ (self, config):
+    def __init__(self, config):
         """Initialize configuration."""
-        super(LCConfigParser, self).__init__()
+        super().__init__()
         self.config = config
 
-    def read (self, files):
+    def read(self, files):
         """Read settings from given config files.
 
         @raises: LinkCheckerError on syntax errors in the config file(s)
         """
         assert isinstance(files, list), "Invalid file list %r" % files
         try:
-            self.read_ok = super(LCConfigParser, self).read(files)
+            self.read_ok = super().read(files)
             if len(self.read_ok) < len(files):
                 failed_files = set(files) - set(self.read_ok)
-                log.warn(LOG_CHECK, "Could not read configuration files %s.", failed_files)
+                log.warn(
+                    LOG_CHECK, "Could not read configuration files %s.", failed_files
+                )
             # Read all the configuration parameters from the given files.
             self.read_checking_config()
             self.read_authentication_config()
@@ -58,15 +68,16 @@ class LCConfigParser (ConfigParser.RawConfigParser, object):
             self.read_output_config()
             self.read_plugin_config()
         except Exception as msg:
-            raise LinkCheckerError(
-              _("Error parsing configuration: %s") % unicode(msg))
+            raise LinkCheckerError(_("Error parsing configuration: %s") % str(msg))
 
-    def read_string_option (self, section, option, allowempty=False):
+    def read_string_option(self, section, option, allowempty=False):
         """Read a string option."""
         if self.has_option(section, option):
             value = self.get(section, option)
             if not allowempty and not value:
-                raise LinkCheckerError(_("invalid empty value for %s: %s\n") % (option, value))
+                raise LinkCheckerError(
+                    _("invalid empty value for %s: %s\n") % (option, value)
+                )
             self.config[option] = value
 
     def read_boolean_option(self, section, option):
@@ -74,24 +85,37 @@ class LCConfigParser (ConfigParser.RawConfigParser, object):
         if self.has_option(section, option):
             self.config[option] = self.getboolean(section, option)
 
-    def read_int_option (self, section, option, key=None, min=None, max=None):
+    def read_int_option(self, section, option, key=None, min=None, max=None):
         """Read an integer option."""
         if self.has_option(section, option):
             num = self.getint(section, option)
             if min is not None and num < min:
                 raise LinkCheckerError(
-                    _("invalid value for %s: %d must not be less than %d") % (option, num, min))
+                    _("invalid value for %s: %d must not be less than %d")
+                    % (option, num, min)
+                )
             if max is not None and num < max:
                 raise LinkCheckerError(
-                    _("invalid value for %s: %d must not be greater than %d") % (option, num, max))
+                    _("invalid value for %s: %d must not be greater than %d")
+                    % (option, num, max)
+                )
             if key is None:
                 key = option
             self.config[key] = num
 
-    def read_output_config (self):
+    def read_output_config(self):
         """Read configuration options in section "output"."""
         section = "output"
         from ..logger import LoggerClasses
+
+        if self.has_section("blacklist"):
+            log.warn(
+                     LOG_CHECK,
+                     _("The blacklist section in linkcheckerrc is deprecated, "
+                       "please rename to failures")
+            )
+            for opt in self.options("blacklist"):
+                self.config["failures"][opt] = self.get("blacklist", opt)
         for c in LoggerClasses:
             key = c.LoggerName
             if self.has_section(key):
@@ -110,6 +134,7 @@ class LCConfigParser (ConfigParser.RawConfigParser, object):
             if self.getboolean(section, "quiet"):
                 self.config['output'] = 'none'
                 self.config['quiet'] = True
+                logconf.reset_loglevel()  # if debug will be overwritten next
         if self.has_option(section, "debug"):
             val = self.get(section, "debug")
             parts = [f.strip().lower() for f in val.split(',')]
@@ -122,15 +147,19 @@ class LCConfigParser (ConfigParser.RawConfigParser, object):
             loggers = self.get(section, "fileoutput").split(",")
             # strip names from whitespace
             loggers = (x.strip().lower() for x in loggers)
-            # no file output for the blacklist and none Logger
+            # no file output for the failures and none Logger
             from ..logger import LoggerNames
-            loggers = (x for x in loggers if x in LoggerNames and
-                       x not in ("blacklist", "none"))
+
+            loggers = (
+                x
+                for x in loggers
+                if x in LoggerNames and x not in ("failures", "none")
+            )
             for val in loggers:
                 output = self.config.logger_new(val, fileoutput=1)
                 self.config['fileoutput'].append(output)
 
-    def read_checking_config (self):
+    def read_checking_config(self):
         """Read configuration options in section "checking"."""
         section = "checking"
         self.read_int_option(section, "threads", min=-1)
@@ -145,10 +174,13 @@ class LCConfigParser (ConfigParser.RawConfigParser, object):
         self.read_int_option(section, "maxfilesizeparse", min=1)
         self.read_int_option(section, "maxfilesizedownload", min=1)
         if self.has_option(section, "allowedschemes"):
-            self.config['allowedschemes'] = [x.strip().lower() for x in \
-                 self.get(section, 'allowedschemes').split(',')]
+            self.config['allowedschemes'] = [
+                x.strip().lower()
+                for x in self.get(section, 'allowedschemes').split(',')
+            ]
         self.read_boolean_option(section, "debugmemory")
         self.read_string_option(section, "cookiefile")
+        self.read_boolean_option(section, "robotstxt")
         self.read_string_option(section, "localwebroot")
         try:
             self.read_boolean_option(section, "sslverify")
@@ -156,7 +188,7 @@ class LCConfigParser (ConfigParser.RawConfigParser, object):
             self.read_string_option(section, "sslverify")
         self.read_int_option(section, "maxrunseconds", min=0)
 
-    def read_authentication_config (self):
+    def read_authentication_config(self):
         """Read configuration options in section "authentication"."""
         section = "authentication"
         password_fields = []
@@ -164,21 +196,29 @@ class LCConfigParser (ConfigParser.RawConfigParser, object):
             for val in read_multiline(self.get(section, "entry")):
                 auth = val.split()
                 if len(auth) == 3:
-                    self.config.add_auth(pattern=auth[0], user=auth[1],
-                                         password=auth[2])
+                    self.config.add_auth(
+                        pattern=auth[0], user=auth[1], password=auth[2]
+                    )
                     password_fields.append("entry/%s/%s" % (auth[0], auth[1]))
                 elif len(auth) == 2:
                     self.config.add_auth(pattern=auth[0], user=auth[1])
                 else:
                     raise LinkCheckerError(
-                       _("missing auth part in entry %(val)r") % {"val": val})
+                        _("missing auth part in entry %(val)r") % {"val": val}
+                    )
         # read login URL and field names
         if self.has_option(section, "loginurl"):
             val = self.get(section, "loginurl").strip()
-            if not (val.lower().startswith("http:") or
-                    val.lower().startswith("https:")):
-                raise LinkCheckerError(_("invalid login URL `%s'. Only " \
-                  "HTTP and HTTPS URLs are supported.") % val)
+            if not (
+                val.lower().startswith("http:") or val.lower().startswith("https:")
+            ):
+                raise LinkCheckerError(
+                    _(
+                        "invalid login URL `%s'. Only "
+                        "HTTP and HTTPS URLs are supported."
+                    )
+                    % val
+                )
             self.config["loginurl"] = val
         self.read_string_option(section, "loginuserfield")
         self.read_string_option(section, "loginpasswordfield")
@@ -200,20 +240,37 @@ class LCConfigParser (ConfigParser.RawConfigParser, object):
             return
         fn = self.read_ok[0]
         if fileutil.is_accessable_by_others(fn):
-            log.warn(LOG_CHECK, "The configuration file %s contains password information (in section [%s] and options %s) and the file is readable by others. Please make the file only readable by you.", fn, section, fields)
+            log.warn(
+                LOG_CHECK,
+                _(
+                    "The configuration file %s contains password information (in"
+                    " section [%s] and options %s) and the file is readable by"
+                    " others. Please make the file only readable by you."
+                ),
+                fn,
+                section,
+                fields,
+            )
             if os.name == 'posix':
                 log.warn(LOG_CHECK, _("For example execute 'chmod go-rw %s'.") % fn)
             elif os.name == 'nt':
-                log.warn(LOG_CHECK, _("See http://support.microsoft.com/kb/308419 for more info on setting file permissions."))
+                log.warn(
+                    LOG_CHECK,
+                    _(
+                        "See %(url)s for more info on setting file permissions."
+                    ) % {"url": "https://support.microsoft.com/kb/308419"}
+                )
 
-    def read_filtering_config (self):
+    def read_filtering_config(self):
         """
         Read configuration options in section "filtering".
         """
         section = "filtering"
         if self.has_option(section, "ignorewarnings"):
-            self.config['ignorewarnings'] = [f.strip().lower() for f in \
-                 self.get(section, 'ignorewarnings').split(',')]
+            self.config['ignorewarnings'] = [
+                f.strip().lower()
+                for f in self.get(section, 'ignorewarnings').split(',')
+            ]
         if self.has_option(section, "ignore"):
             for line in read_multiline(self.get(section, "ignore")):
                 pat = get_link_pat(line, strict=1)
