@@ -1,4 +1,3 @@
-# -*- coding: iso-8859-1 -*-
 # Copyright (C) 2006-2014 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
@@ -27,7 +26,7 @@ from .. import parser
 QUEUE_POLL_INTERVALL_SECS = 1.0
 
 
-def check_urls (urlqueue, logger):
+def check_urls(urlqueue, logger):
     """Check URLs without threading."""
     while not urlqueue.empty():
         url_data = urlqueue.get()
@@ -69,8 +68,8 @@ def check_url(url_data, logger):
             # copy data from cache and adjust it
             result = copy.copy(result)
             result.parent_url = url_data.parent_url
-            result.base_ref = url_data.base_ref or u""
-            result.base_url = url_data.base_url or u""
+            result.base_ref = url_data.base_ref or ""
+            result.base_url = url_data.base_url or ""
             result.line = url_data.line
             result.column = url_data.column
             result.level = url_data.recursion_level
@@ -81,21 +80,21 @@ def check_url(url_data, logger):
 class Checker(task.LoggedCheckedTask):
     """URL check thread."""
 
-    def __init__ (self, urlqueue, logger, add_request_session):
+    def __init__(self, urlqueue, logger, add_request_session):
         """Store URL queue and logger."""
-        super(Checker, self).__init__(logger)
+        super().__init__(logger)
         self.urlqueue = urlqueue
-        self.origname = self.getName()
+        self.origname = self.name
         self.add_request_session = add_request_session
 
-    def run_checked (self):
+    def run_checked(self):
         """Check URLs in the queue."""
         # construct per-thread HTTP/S requests session
         self.add_request_session()
         while not self.stopped(0):
             self.check_url()
 
-    def check_url (self):
+    def check_url(self):
         """Try to get URL data from queue and check it."""
         try:
             url_data = self.urlqueue.get(timeout=QUEUE_POLL_INTERVALL_SECS)
@@ -104,17 +103,13 @@ class Checker(task.LoggedCheckedTask):
                     self.check_url_data(url_data)
                 finally:
                     self.urlqueue.task_done(url_data)
-                self.setName(self.origname)
+                self.name = self.origname
         except urlqueue.Empty:
             pass
         except Exception:
             self.internal_error()
 
-    def check_url_data (self, url_data):
+    def check_url_data(self, url_data):
         """Check one URL data instance."""
-        if url_data.url is None:
-            url = ""
-        else:
-            url = url_data.url.encode("ascii", "replace")
-        self.setName("CheckThread-%s" % url)
+        self.name = "CheckThread-%s" % (url_data.url or "")
         check_url(url_data, self.logger)
