@@ -1,4 +1,3 @@
-# -*- coding: iso-8859-1 -*-
 # Copyright (C) 2000-2014 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
@@ -18,15 +17,22 @@
 Functions used by the WSGI script.
 """
 
-import cgi
-import os
+import html
 import threading
 import locale
 import re
 import time
-import urlparse
-from . import configuration, strformat, checker, director, get_link_pat, \
-    init_i18n, url as urlutil
+import urllib.parse
+
+from . import (
+    configuration,
+    strformat,
+    checker,
+    director,
+    get_link_pat,
+    init_i18n,
+    url as urlutil,
+)
 from .decorators import synchronized
 
 # 5 minutes timeout for requests
@@ -50,7 +56,7 @@ def application(environ, start_response):
         request_body = environ['wsgi.input'].read(request_body_size)
     else:
         request_body = environ['wsgi.input'].read()
-    form = cgi.parse_qs(request_body)
+    form = urllib.parse.parse_qs(request_body.decode(HTML_ENCODING))
 
     status = '200 OK'
     start_response(status, get_response_headers())
@@ -67,20 +73,23 @@ lang_locale = {
 }
 _is_level = re.compile(r'^(0|1|2|3|-1)$').match
 
-class LCFormError (StandardError):
+
+class LCFormError(Exception):
     """Form related errors."""
+
     pass
 
 
 def get_response_headers():
     """Get list of response headers in key-value form."""
-    return [("Content-type", "text/html"),
-            ("Cache-Control", "no-cache"),
-            ("Pragma:", "no-cache")
-           ]
+    return [
+        ("Content-type", "text/html"),
+        ("Cache-Control", "no-cache"),
+        ("Pragma:", "no-cache"),
+    ]
 
 
-def formvalue (form, key):
+def formvalue(form, key):
     """Get value with given key from WSGI form."""
     field = form.get(key)
     if isinstance(field, list):
@@ -89,7 +98,9 @@ def formvalue (form, key):
 
 
 _lock = threading.Lock()
-class ThreadsafeIO (object):
+
+
+class ThreadsafeIO:
     """Thread-safe unicode I/O class."""
 
     def __init__(self):
@@ -98,23 +109,23 @@ class ThreadsafeIO (object):
         self.closed = False
 
     @synchronized(_lock)
-    def write (self, data):
+    def write(self, data):
         """Write given unicode data to buffer."""
-        assert isinstance(data, unicode)
+        assert isinstance(data, str)
         if self.closed:
             raise IOError("Write on closed I/O object")
         if data:
             self.buf.append(data)
 
     @synchronized(_lock)
-    def get_data (self):
+    def get_data(self):
         """Get bufferd unicode data."""
-        data = u"".join(self.buf)
+        data = "".join(self.buf)
         self.buf = []
         return data
 
     @synchronized(_lock)
-    def close (self):
+    def close(self):
         """Reset buffer and close this I/O object."""
         self.buf = []
         self.closed = True
@@ -125,15 +136,15 @@ def encode(s):
     return s.encode(HTML_ENCODING, 'ignore')
 
 
-def checklink (form=None, env=os.environ):
+def checklink(form, env):
     """Validates the CGI form and checks the given links."""
     if form is None:
         form = {}
     try:
         checkform(form, env)
-    except LCFormError as errmsg:
-        log(env, errmsg)
-        yield encode(format_error(errmsg))
+    except LCFormError as err:
+        log(env, err)
+        yield encode(format_error(str(err)))
         return
     out = ThreadsafeIO()
     config = get_configuration(form, out)
@@ -146,7 +157,7 @@ def checklink (form=None, env=os.environ):
     out.close()
 
 
-def start_check (aggregate, out):
+def start_check(aggregate, out):
     """Start checking in background and write encoded output to out."""
     # check in background
     t = threading.Thread(target=director.check_urls, args=(aggregate,))
@@ -170,6 +181,7 @@ def get_configuration(form, out):
     config = configuration.Configuration()
     config["recursionlevel"] = int(formvalue(form, "level"))
     config["logger"] = config.logger_new('html', fd=out, encoding=HTML_ENCODING)
+    config["status"] = False
     config["threads"] = 2
     if "anchors" in form:
         config["enabledplugins"].append("AnchorCheck")
@@ -182,12 +194,12 @@ def get_configuration(form, out):
     return config
 
 
-def get_host_name (form):
+def get_host_name(form):
     """Return host name of given URL."""
-    return urlparse.urlparse(formvalue(form, "url"))[1]
+    return urllib.parse.urlparse(formvalue(form, "url"))[1]
 
 
-def checkform (form, env):
+def checkform(form, env):
     """Check form data. throw exception on error
     Be sure to NOT print out any user-given data as HTML code, so use
     only plain strings as exception text."""
@@ -226,28 +238,31 @@ def checkform (form, env):
                 raise LCFormError(_("invalid %s option %r") % (option, value))
 
 
-def log (env, msg):
+def log(env, msg):
     """Log message to WSGI error output."""
     logfile = env['wsgi.errors']
-    logfile.write(msg + "\n")
+    logfile.write("%s\n" % msg)
 
 
-def dump (env, form):
+def dump(env, form):
     """Log environment and form."""
     for var, value in env.items():
-        log(env, var+"="+value)
+        log(env, var + "=" + value)
     for key in form:
         log(env, str(formvalue(form, key)))
 
 
-def format_error (why):
+def format_error(why):
     """Format standard error page.
+
     @param why: error message
-    @ptype why: unicode
+    @type why: unicode
     @return: HTML page content
     @rtype: unicode
     """
-    return _("""<!DOCTYPE HTML>
+    return (
+        _(
+            """<!DOCTYPE HTML>
 <html><head>
 <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1">
 <title>LinkChecker Online Error</title></head>
@@ -260,4 +275,7 @@ contains only these characters: <code>A-Za-z0-9./_~-</code><br/><br/>
 Errors are logged.
 </blockquote>
 </body>
-</html>""") % cgi.escape(why)
+</html>"""
+        )
+        % html.escape(why)
+    )
