@@ -1,4 +1,3 @@
-# -*- coding: iso-8859-1 -*-
 # Copyright (C) 2005-2014 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
@@ -27,6 +26,7 @@ from .logconf import LOG_CHECK
 
 mimedb = None
 
+
 def init_mimedb():
     """Initialize the local MIME database."""
     global mimedb
@@ -52,15 +52,17 @@ def add_mimetype(mimedb, mimetype, extension):
 
 # if file extension lookup was unsuccessful, look at the content
 PARSE_CONTENTS = {
-    "text/html": re.compile(r'^(?i)<(!DOCTYPE html|html|head|title)'),
+    "text/html": re.compile(r'^<(!DOCTYPE html|html|head|title)', re.IGNORECASE),
     "text/plain+opera": re.compile(r'^Opera Hotlist'),
     "text/plain+chromium": re.compile(r'^{\s*"checksum":'),
-    "text/plain+linkchecker": re.compile(r'(?i)^# LinkChecker URL list'),
-    "application/xml+sitemapindex": re.compile(r'(?i)<\?xml[^<]+<sitemapindex\s+'),
-    "application/xml+sitemap": re.compile(r'(?i)<\?xml[^<]+<urlset\s+'),
+    "text/plain+linkchecker": re.compile(r'^# LinkChecker URL list', re.IGNORECASE),
+    "application/xml+sitemapindex": re.compile(r'(<\?xml[^<]+)?<sitemapindex\s+',
+                                               re.IGNORECASE),
+    "application/xml+sitemap": re.compile(r'(<\?xml[^<]+)?<urlset\s+', re.IGNORECASE),
 }
 
-def guess_mimetype (filename, read=None):
+
+def guess_mimetype(filename, read=None):
     """Return MIME type of file, or 'application/octet-stream' if it could
     not be determined."""
     mime, encoding = None, None
